@@ -36,7 +36,7 @@ Copyright (C) 1994 Steen Lumholt.
  * be relinquished by _tkinter, so if a Tcl/Tk call blocks no other Python
  * thread will be able to run.
  *
- * Tom G. 1/30/04.
+ * Tom Goddard, 1/30/04.
  */
 #undef WITH_THREAD
 
@@ -48,10 +48,6 @@ Copyright (C) 1994 Steen Lumholt.
 #include <windows.h>
 #endif
 
-#ifdef macintosh
-#define MAC_TCL
-#endif
-
 /* Allow using this code in Python 2.[12] */
 #ifndef PyDoc_STRVAR
 #define PyDoc_STRVAR(name,str) static char name[] = str
@@ -111,15 +107,7 @@ Copyright (C) 1994 Steen Lumholt.
 #error "unsupported Tcl configuration"
 #endif
 
-#if defined(macintosh)
-/* Sigh, we have to include this to get at the tcl qd pointer */
-#include <tkMac.h>
-/* And this one we need to clear the menu bar */
-#include <Menus.h>
-#endif
-
-#if !(defined(MS_WINDOWS) || defined(__CYGWIN__) || defined(macintosh))
-/* Mac has it, but it doesn't really work:-( */
+#if !(defined(MS_WINDOWS) || defined(__CYGWIN__))
 #define HAVE_CREATEFILEHANDLER
 #endif
 
@@ -253,29 +241,6 @@ static PyThreadState *tcl_tstate = NULL;
 
 #endif
 
-#ifdef macintosh
-
-/*
-** Additional cruft needed by Tcl/Tk on the Mac.
-** This is for Tcl 7.5 and Tk 4.1 (patch release 1).
-*/
-
-/* ckfree() expects a char* */
-#define FREECAST (char *)
-
-#include <Events.h> /* For EventRecord */
-
-typedef int (*TclMacConvertEventPtr) (EventRecord *eventPtr);
-void Tcl_MacSetEventProc(TclMacConvertEventPtr procPtr);
-int TkMacConvertEvent(EventRecord *eventPtr);
-
-static int PyMacConvertEvent(EventRecord *eventPtr);
-
-#include <SIOUX.h>
-extern int SIOUXIsAppWindow(WindowPtr);
-
-#endif /* macintosh */
-
 #ifndef FREECAST
 #define FREECAST (char *)
 #endif
@@ -596,15 +561,19 @@ int
 Tcl_AppInit(Tcl_Interp *interp)
 {
 	Tk_Window main;
+	const char * _tkinter_skip_tk_init;
 
-	main = Tk_MainWindow(interp);
 	if (Tcl_Init(interp) == TCL_ERROR) {
 		PySys_WriteStderr("Tcl_Init error: %s\n", Tcl_GetStringResult(interp));
 		return TCL_ERROR;
 	}
-	if (Tk_Init(interp) == TCL_ERROR) {
-		PySys_WriteStderr("Tk_Init error: %s\n", Tcl_GetStringResult(interp));
-		return TCL_ERROR;
+	_tkinter_skip_tk_init =	Tcl_GetVar(interp, "_tkinter_skip_tk_init", TCL_GLOBAL_ONLY);
+	if (_tkinter_skip_tk_init == NULL || strcmp(_tkinter_skip_tk_init, "1")	!= 0) {
+		main = Tk_MainWindow(interp);
+		if (Tk_Init(interp) == TCL_ERROR) {
+			PySys_WriteStderr("Tk_Init error: %s\n", Tcl_GetStringResult(interp));
+			return TCL_ERROR;
+		}
 	}
 	return TCL_OK;
 }
@@ -622,7 +591,7 @@ static void DisableEventHook(void); /* Forward */
 
 static TkappObject *
 Tkapp_New(char *screenName, char *baseName, char *className,
-	  int interactive, int wantobjects)
+	  int interactive, int wantobjects, int	wantTk, int sync, char *use)
 {
 	TkappObject *v;
 	char *argv0;
@@ -661,12 +630,6 @@ Tkapp_New(char *screenName, char *baseName, char *className,
 	v->ProcBodyType = Tcl_GetObjType("procbody");
 	v->StringType = Tcl_GetObjType("string");
 
-#if defined(macintosh)
-	/* This seems to be needed */
-	ClearMenuBar();
-	TkMacInitMenus(v->interp);
-#endif
-
 	/* Delete the 'exit' command, which can screw things up */
 	Tcl_DeleteCommand(v->interp, "exit");
 
@@ -693,6 +656,41 @@ Tkapp_New(char *screenName, char *baseName, char *className,
 	Tcl_SetVar(v->interp, "argv0", argv0, TCL_GLOBAL_ONLY);
 	ckfree(argv0);
 
+	if (! wantTk) {
+	    Tcl_SetVar(v->interp, "_tkinter_skip_tk_init", "1",	TCL_GLOBAL_ONLY);
+	}
+
+	/* some initial arguments need to be in argv */
+	if (sync || use) {
+		char *args;
+		int len = 0;
+
+		if (sync)
+			len += sizeof "-sync";
+		if (use)
+			len += strlen(use) + sizeof "-use ";
+
+		args = (char*)ckalloc(len);
+		if (!args) {
+			PyErr_NoMemory();
+			Py_DECREF(v);
+			return NULL;
+		}
+
+		args[0] = '\0';
+		if (sync)
+			strcat(args, "-sync");
+		if (use) {
+			if (sync)
+				strcat(args, " ");
+			strcat(args, "-use ");
+			strcat(args, use);
+		}
+
+		Tcl_SetVar(v->interp, "argv", args, TCL_GLOBAL_ONLY);
+		ckfree(args);
+	}
+
 	if (Tcl_AppInit(v->interp) != TCL_OK)
 		return (TkappObject *)Tkinter_Error((PyObject *)v);
 
@@ -822,8 +820,8 @@ static PyObject *
 PyTclObject_repr(PyTclObject *self)
 {
 	char buf[50];
-	PyOS_snprintf(buf, 50, "<%s object at 0x%.8x>",
-		      self->value->typePtr->name, (int)self->value);
+	PyOS_snprintf(buf, 50, "<%s object at %p>",
+		      self->value->typePtr->name, self->value);
 	return PyString_FromString(buf);
 }
 
@@ -846,6 +844,10 @@ get_typename(PyTclObject* obj, void* ignored)
 	return PyString_FromString(obj->value->typePtr->name);
 }
 
+/*
+ * Added generic_get_attr() wrapper function because static function is
+ * needed below in PyTclObject_Type initializer.  Tom Goddard, 2/9/2006
+ */
 static PyObject *
 generic_get_attr(PyObject *a1, PyObject *a2)
 {
@@ -860,8 +862,10 @@ static PyGetSetDef PyTclObject_getsetlist[] = {
 };
 
 static PyMethodDef PyTclObject_methods[] = {
+#ifdef Py_USING_UNICODE
 	{"__unicode__",	(PyCFunction)PyTclObject_unicode, METH_NOARGS,
 	PyTclObject_unicode__doc__},
+#endif
 	{0}
 };
 
@@ -884,7 +888,7 @@ statichere PyTypeObject PyTclObject_Type = {
 	0,			/*tp_hash*/
         0,                      /*tp_call*/
         (reprfunc)PyTclObject_str,        /*tp_str*/
-        generic_get_attr	,/*tp_getattro*/
+        generic_get_attr,	/*tp_getattro*/
         0,                      /*tp_setattro*/
         0,                      /*tp_as_buffer*/
         Py_TPFLAGS_DEFAULT,     /*tp_flags*/
@@ -1013,7 +1017,7 @@ FromObj(PyObject* tkapp, Tcl_Obj *value)
 			}
 		}
 #else
-		res = PyString_FromStringAndSize(value->bytes, value->length);
+		result = PyString_FromStringAndSize(value->bytes, value->length);
 #endif
 		return result;
 	}
@@ -2623,6 +2627,39 @@ Tkapp_InterpAddr(PyObject *self, PyObject *args)
 	return PyInt_FromLong((long)Tkapp_Interp(self));
 }
 
+static PyObject	*
+Tkapp_TkInit(PyObject *self, PyObject *args)
+{
+	Tcl_Interp *interp = Tkapp_Interp(self);
+	Tk_Window main_window;
+	const char * _tk_exists = NULL;
+	PyObject *res =	NULL;
+	int err;
+	main_window = Tk_MainWindow(interp);
+
+	/* We want to guard against calling Tk_Init() multiple times */
+	CHECK_TCL_APPARTMENT;
+	ENTER_TCL
+	err = Tcl_Eval(Tkapp_Interp(self), "info exists	tk_version");
+	ENTER_OVERLAP
+	if (err == TCL_ERROR) {
+		res = Tkinter_Error(self);
+	} else {
+		_tk_exists = Tkapp_Result(self);
+	}
+	LEAVE_OVERLAP_TCL
+	if (err == TCL_ERROR) {
+		return NULL;
+	}
+	if (_tk_exists == NULL || strcmp(_tk_exists, "1") != 0)	{
+		if (Tk_Init(interp)	== TCL_ERROR) {
+		        PyErr_SetString(Tkinter_TclError, Tcl_GetStringResult(Tkapp_Interp(self)));
+			return NULL;
+		}
+	}
+	Py_INCREF(Py_None);
+	return Py_None;
+}
 
 static PyObject *
 Tkapp_WantObjects(PyObject *self, PyObject *args)
@@ -2690,6 +2727,7 @@ static PyMethodDef Tkapp_methods[] =
 	{"dooneevent", 	       Tkapp_DoOneEvent, METH_VARARGS},
 	{"quit", 	       Tkapp_Quit, METH_VARARGS},
 	{"interpaddr",         Tkapp_InterpAddr, METH_VARARGS},
+	{"loadtk",	       Tkapp_TkInit, METH_NOARGS},
 	{NULL, 		       NULL}
 };
 
@@ -2854,6 +2892,9 @@ Tkinter_Create(PyObject *self, PyObject *args)
 	char *className = NULL;
 	int interactive = 0;
 	int wantobjects = 0;
+	int wantTk = 1;	/* If false, then Tk_Init() doesn't get	called */
+	int sync = 0; /* pass -sync to wish */
+	char *use = NULL; /* pass -use to wish */
 
 	baseName = strrchr(Py_GetProgramName(), '/');
 	if (baseName != NULL)
@@ -2862,13 +2903,15 @@ Tkinter_Create(PyObject *self, PyObject *args)
 		baseName = Py_GetProgramName();
 	className = "Tk";
   
-	if (!PyArg_ParseTuple(args, "|zssii:create",
+	if (!PyArg_ParseTuple(args, "|zssiiiiz:create",
 			      &screenName, &baseName, &className,
-			      &interactive, &wantobjects))
+			      &interactive, &wantobjects, &wantTk,
+			      &sync, &use))
 		return NULL;
 
 	return (PyObject *) Tkapp_New(screenName, baseName, className, 
-				      interactive, wantobjects);
+				      interactive, wantobjects,	wantTk,
+				      sync, use);
 }
 
 static PyObject *
@@ -2965,6 +3008,7 @@ EventHook(void)
 			break;
 		}
 #endif
+/* Changed #if condition.  Tom Goddard, 2/9/2006 */
 #if defined(WITH_THREAD)
 		Py_BEGIN_ALLOW_THREADS
 		if(tcl_lock)PyThread_acquire_lock(tcl_lock, 1);
@@ -3112,112 +3156,4 @@ init_tkinter(void)
 	Py_AtExit(Tcl_Finalize);
 #endif
 
-#ifdef macintosh
-	/*
-	** Part of this code is stolen from MacintoshInit in tkMacAppInit.
-	** Most of the initializations in that routine (toolbox init calls and
-	** such) have already been done for us, so we only need these.
-	*/
-	tcl_macQdPtr = &qd;
-
-	Tcl_MacSetEventProc(PyMacConvertEvent);
-#if GENERATINGCFM
-	mac_addlibresources();
-#endif /* GENERATINGCFM */
-#endif /* macintosh */
 }
-
-
-
-#ifdef macintosh
-
-/*
-** Anyone who embeds Tcl/Tk on the Mac must define panic().
-*/
-
-void
-panic(char * format, ...)
-{
-	va_list varg;
-	
-	va_start(varg, format);
-	
-	vfprintf(stderr, format, varg);
-	(void) fflush(stderr);
-	
-	va_end(varg);
-
-	Py_FatalError("Tcl/Tk panic");
-}
-
-/*
-** Pass events to SIOUX before passing them to Tk.
-*/
-
-static int
-PyMacConvertEvent(EventRecord *eventPtr)
-{
-	WindowPtr frontwin;
-	/*
-	** Sioux eats too many events, so we don't pass it everything.  We
-	** always pass update events to Sioux, and we only pass other events if
-	** the Sioux window is frontmost. This means that Tk menus don't work
-	** in that case, but at least we can scroll the sioux window.
-	** Note that the SIOUXIsAppWindow() routine we use here is not really
-	** part of the external interface of Sioux...
-	*/
-	frontwin = FrontWindow();
-	if ( eventPtr->what == updateEvt || SIOUXIsAppWindow(frontwin) ) {
-		if (SIOUXHandleOneEvent(eventPtr))
-			return 0; /* Nothing happened to the Tcl event queue */
-	}
-	return TkMacConvertEvent(eventPtr);
-}
-
-#if GENERATINGCFM
-
-/*
-** Additional Mac specific code for dealing with shared libraries.
-*/
-
-#include <Resources.h>
-#include <CodeFragments.h>
-
-static int loaded_from_shlib = 0;
-static FSSpec library_fss;
-
-/*
-** If this module is dynamically loaded the following routine should
-** be the init routine. It takes care of adding the shared library to
-** the resource-file chain, so that the tk routines can find their
-** resources.
-*/
-OSErr pascal
-init_tkinter_shlib(CFragInitBlockPtr data)
-{
-	__initialize();
-	if ( data == nil ) return noErr;
-	if ( data->fragLocator.where == kDataForkCFragLocator ) {
-		library_fss = *data->fragLocator.u.onDisk.fileSpec;
-		loaded_from_shlib = 1;
-	} else if ( data->fragLocator.where == kResourceCFragLocator ) {
-		library_fss = *data->fragLocator.u.inSegs.fileSpec;
-		loaded_from_shlib = 1;
-	}
-	return noErr;
-}
-
-/*
-** Insert the library resources into the search path. Put them after
-** the resources from the application. Again, we ignore errors.
-*/
-static
-mac_addlibresources(void)
-{
-	if ( !loaded_from_shlib ) 
-		return;
-	(void)FSpOpenResFile(&library_fss, fsRdPerm);
-}
-
-#endif /* GENERATINGCFM */
-#endif /* macintosh */
