@@ -344,7 +344,7 @@ static bool builtin_menu_accelerator(Session &s, const Stringy &accel, void *)
   else if (accel == "r4") show_resonance_peaks(s, xp, 3);
   else if (accel == "sl") selected_peak_list(s);
   else if (accel == "cr") show_ornament_color_dialog(s);
-  else if (accel == "oz") show_ornament_size_dialog(s);
+  else if (accel == "oz") show_ornament_size_dialog(s, sp);
   else if (accel == "he") show_help(s, "manual");
   else if (accel == "hi") show_help(s, "intro");
   else if (accel == "hf") show_help(s, "files");
