@@ -4,6 +4,8 @@
 #ifndef CONTOURSTREAM_HEADER_INCLUDED
 #define CONTOURSTREAM_HEADER_INCLUDED
 
+#include <stdlib.h>		// use size_t
+
 class Drawing_Routines;
 
 class ContourStream {
@@ -13,7 +15,7 @@ public:
 
 	void		addContour(float lev, int n, float *x, float *y);
 	void		free_extra_memory();
-	int		memory_use() const;
+	size_t		memory_use() const;
 
 	void		display(Drawing_Routines &dr);
 
