@@ -6,7 +6,7 @@
  * a label showing an assignment).
  *
  */
-#include <math.h>		// Use atan2()
+#include <math.h>		// Use atan2(), fabs()
 #include <string.h>		// Use strcmp()
 
 #include "axismap.h"		// Use Axis_Map
@@ -602,12 +602,12 @@ bool Label::pointer_triangle(ODraw &dr, double aspect,
 		pointerLab1Y = labelCenterY + deltaY - labelYDelta * factor;
 		pointerLab2Y = labelCenterY - deltaY - labelYDelta * factor;
 	}
-	else if (is_between(abs(aOL), 135, 180)
-		 && is_between(abs(aOR), 135, 180)) {
+	else if (is_between(fabs(aOL), 135, 180)
+		 && is_between(fabs(aOR), 135, 180)) {
 		/*
 		 * case C, label left of peak
 		 */
-		factor = (aOR / abs(aOR)) * (180 - abs(aOR)) / 45;
+		factor = (aOR / fabs(aOR)) * (180 - fabs(aOR)) / 45;
 		factor = labelCenterY > peakCenterY
 			? max(factor, 0.0) : min(factor, 0.0);
 
