@@ -484,6 +484,7 @@ static bool read_nih_header(FILE *nihfile, const Stringy &path,
     { *error_msg = header_error; return false; }
   h->dim = (int) dimen;
 
+  int aname[MAXNIHDIM];
   for (int d = 0 ; d < h->dim ; ++d)
     {
       float size, complex;
@@ -505,16 +506,8 @@ static bool read_nih_header(FILE *nihfile, const Stringy &path,
       if (!read_nih_float(order[d], nihfile, bigend, &aorder))
 	{ *error_msg = header_error; return false; }
 
+      aname[d] = (int) aorder;
       int dnum = (int) aorder - 1;
-
-      //
-      // Map the bruk2pipe, var2pipe default order 2134 to descending order.
-      // For 2d data to 21, 3d data 321, 4d data 4321.
-      //
-      h->axis_number[d] = (dnum == 1 ? h->dim - 1 :
-			   (dnum == 0 ? h->dim - 2 :
-			    h->dim - dnum - 1));
-
       if (!read_nih_float(sw[dnum], nihfile, bigend, &h->spectral_width[d]) ||
 	  !read_nih_float(xf[dnum], nihfile, bigend, &h->xmtr_freq[d]) ||
 	  !read_nih_float(of[dnum], nihfile, bigend, &h->origin_freq[d]) ||
@@ -524,6 +517,29 @@ static bool read_nih_header(FILE *nihfile, const Stringy &path,
       h->nucleus[d] = read_nih_label(nuc[dnum], nihfile);
     }
 
+  //
+  // Map nmrPipe axis names 4,3,1,2 to Sparky axis numbers in that order.
+  // Even 2-D spectra (projections) can have nmrPipe axis names 3 or 4.
+  //
+  int sparky_order[MAXNIHDIM] = {4, 3, 1, 2};
+  int axis = 0;
+  for (int a = 0 ; a < MAXNIHDIM ; ++a)
+    for (int d = 0 ; d < h->dim ; ++d)
+      if (aname[d] == sparky_order[a])
+	{
+	  h->axis_number[d] = axis;
+	  axis += 1;
+	}
+  if (axis != h->dim)
+    {
+      Stringy msg = "Axis names must be 1, 2, 3, or 4, got";
+      for (int d = 0 ; d < h->dim ; ++d)
+	msg = msg + formatted_string(" %d", aname[d]);
+      *error_msg = msg;
+      return false;
+    }
+      
+
   //
   // Check if file is too small.
   //
