@@ -2,7 +2,7 @@
 // NMR data file reading and writing.
 //
 
-#include <iostream.h>		// use ostream
+#include <iostream>		// use ostream
 #include <math.h>		// use fabs()
 
 #include "blockfile.h"		// Use Block_File, block_region()
@@ -10,6 +10,7 @@
 #include "memalloc.h"		// use new()
 #include "nmrdata.h"		// Use NMR_Data
 #include "spoint.h"		// Use SPoint, IPoint
+#include "subarray.h"		// use Subarray_Iterator
 
 static List permuted_label_list(NMR_Data *nmr_data, const IPoint &new_order);
 static SPoint region_spectrum_width(NMR_Data *nmr_data, const IRegion &region);
@@ -146,9 +147,9 @@ bool Permuted_NMR_Data::read_values(const IRegion &index_region, float *values)
       Subarray_Iterator vi(index_region, index_region, true);
       for ( ; !vi.finished() ; vi.next())
 	{
-	  int k = vi.index();
-	  int unperm_k = position_index(vi.position().unpermute(new_order),
-					unperm_region, true);
+	  offset_type k = vi.index();
+	  offset_type unperm_k = position_index(vi.position().unpermute(new_order),
+					 unperm_region, true);
 	  values[k] = unperm_values[unperm_k];
 	}
     }
@@ -324,8 +325,8 @@ bool Thresholded_NMR_Data::read_values(const IRegion &r, float *values)
   bool read = nmr_data->read_values(r, values);
   if (read)
     {
-      int volume = r.volume();
-      for (int k = 0 ; k < volume ; ++k)
+      size_t volume = r.volume();
+      for (size_t k = 0 ; k < volume ; ++k)
 	if (values[k] > neg_threshold && values[k] < pos_threshold)
 	  values[k] = 0;
     }
@@ -416,9 +417,9 @@ bool Squished_NMR_Data::read_value(const IPoint &index, float *value)
   if (!nmr_data->read_values(iregion, values))
     return false;
 
-  int size = cell_size.product();
+  size_t size = cell_size.product();
   float max_value = 0, min_value = 0;
-  for (int k = 0 ; k < size ; ++k)
+  for (size_t k = 0 ; k < size ; ++k)
     {
       if (values[k] > max_value)
 	max_value = values[k];
@@ -437,7 +438,7 @@ bool Squished_NMR_Data::read_values(const IRegion &index_region, float *values)
   IPoint i = index_region.first_point();
   do
     {
-      int index = position_index(i, index_region, true);
+      offset_type index = position_index(i, index_region, true);
       if (!read_value(i, values + index))
 	return false;
     }
@@ -505,8 +506,8 @@ bool Projected_NMR_Data::read_values(const IRegion &index_region,
   IRegion base(index_region.min.insert_component(axis, 0),
 	       index_region.max.insert_component(axis, 0));
 
-  int volume = index_region.volume();
-  for (int k = 0 ; k < volume; ++k)
+  size_t volume = index_region.volume();
+  for (size_t k = 0 ; k < volume; ++k)
     values[k] = 0;
 
   //
@@ -538,7 +539,7 @@ bool Projected_NMR_Data::read_values(const IRegion &index_region,
 	      if (h > max_h) max_h = h;
 	    }
 	  float extreme = (max_h >= -min_h ? max_h : min_h);
-	  int vindex = vi.index();
+	  offset_type vindex = vi.index();
 	  float value = values[vindex];
 	  if (fabs(extreme) > fabs(value))
 	    values[vindex] = extreme;
@@ -651,14 +652,14 @@ Stringy standard_nucleus_name(const Stringy &nucleus)
 
 // ----------------------------------------------------------------------------
 //
-void NMR_Data::print_header(ostream &out)
+void NMR_Data::print_header(std::ostream &out)
 {
   int dim = dimension();
 
   Stringy heading = formatted_string("%-20s", "axis");
   for (int a = 0 ; a < dim ; ++a)
     heading = heading + formatted_string("%11s%1d", "w", a+1);
-  out << heading << endl;
+  out << heading << std::endl;
 
   SPoint spectrum_width_ppm(dim);
   for (int a = 0 ; a < dim ; ++a)
@@ -667,13 +668,14 @@ void NMR_Data::print_header(ostream &out)
       spectrum_width_ppm[a] = (sfreq == 0 ? 0 : spectrum_width()[a] / sfreq);
     }
 
-  out << header_line("nucleus", axis_label_list()) << endl;
-  out << header_line("matrix size", size()) << endl;
-  out << header_line("block size", block_size()) << endl;
-  out << header_line("upfield ppm", origin_ppm() - spectrum_width_ppm) << endl;
-  out << header_line("downfield ppm", origin_ppm()) << endl;
-  out << header_line("spectrum width Hz", spectrum_width()) << endl;
-  out << header_line("transmitter MHz", spectrometer_frequency()) << endl;
+  out << header_line("nucleus", axis_label_list()) << std::endl;
+  out << header_line("matrix size", size()) << std::endl;
+  out << header_line("block size", block_size()) << std::endl;
+  out << header_line("upfield ppm", origin_ppm() - spectrum_width_ppm)
+      << std::endl;
+  out << header_line("downfield ppm", origin_ppm()) << std::endl;
+  out << header_line("spectrum width Hz", spectrum_width()) << std::endl;
+  out << header_line("transmitter MHz", spectrometer_frequency()) << std::endl;
 }
 
 // ----------------------------------------------------------------------------
@@ -744,8 +746,8 @@ bool Dataless_NMR_Data::read_value(const IPoint &, float *value)
   { *value = 0; return 1; }
 bool Dataless_NMR_Data::read_values(const IRegion &region, float *values)
 {
-  int size = region.volume();
-  for (int i = 0 ; i < size ; ++i)
+  size_t size = region.volume();
+  for (size_t i = 0 ; i < size ; ++i)
     values[i] = 0;
   return 1;
 }
