@@ -1,7 +1,7 @@
 /*
  * Support for printing of spectra in postscript format.
  */
-#include <math.h>
+#include <math.h>		// use fabs
 #include <stdlib.h>		// use getenv()
 #include <time.h>
 
@@ -239,11 +239,11 @@ static Print_Layout compute_layout(View *vp, Rectangle r,
       height = inch_to_cm(height);
 
       double x_page_size = vp->scale(po.fixed_scales[0], X, PPM, u) * width;
-      double x_size = abs(layout.start[0]-layout.end[0]);
+      double x_size = fabs(layout.start[0]-layout.end[0]);
       layout.pages[0] = (x_page_size > 0 ? (int) ceil(x_size/x_page_size) : 1);
 
       double y_page_size = vp->scale(po.fixed_scales[1], Y, PPM, u) * height;
-      double y_size = abs(layout.start[1]-layout.end[1]);
+      double y_size = fabs(layout.start[1]-layout.end[1]);
       layout.pages[1] = (y_page_size > 0 ? (int) ceil(y_size/y_page_size) : 1);
     }
   else
@@ -282,7 +282,7 @@ static int number_of_ticks(double incr)
 {
 	int ticks = 5;			/* the default value */
 
-	incr = abs(incr);
+	incr = fabs(incr);
 
 	if (incr == 0)
 	  return ticks;
@@ -514,8 +514,8 @@ _printPage(
   if (opt.fixed_scale) {
     double scx = vp->scale(max(opt.fixed_scales[0], .001), X, PPM, u);
     double scy = vp->scale(max(opt.fixed_scales[1], .001), Y, PPM, u);
-    width = cm_to_inch(abs(bl_x - tr_x) / scx);
-    height = cm_to_inch(abs(bl_y - tr_y) / scy);
+    width = cm_to_inch(fabs(bl_x - tr_x) / scx);
+    height = cm_to_inch(fabs(bl_y - tr_y) / scy);
   }
 
   //
@@ -788,7 +788,7 @@ static void resonance_print(FILE *fp, View *view, Axis a,
   /*
    * Initialize the font
    */
-  int font_size = round(72 * font_height * scale / dpi); // Point size
+  int font_size = nearest_int(72 * font_height * scale / dpi); // Point size
   fprintf(fp, "/XfR /%s bindFont XfR\n", RESFONTNAME);
   fprintf(fp, "/resScale %d SC def\n", font_size);
 //  fprintf(fp, "/resScale %d SC def\n", RESFONTSIZE);
@@ -901,7 +901,7 @@ static int _printProlog(FILE *to, View *vp)
 	fprintf(to, "/SparkyMajorVersion %d def\n",  SPARKY_VERSION);
 	fprintf(to, "/SparkyMinorVersion %d def\n",  SPARKY_RELEASE);
 	fprintf(to, "/SCALE %f def\n", (double) UPI / DPI);
-	fprintf(to, "/PEAKLINEWIDTH %d def\n", round(0.015 * DPI));
+	fprintf(to, "/PEAKLINEWIDTH %d def\n", nearest_int(0.015 * DPI));
 
 	/*
 	 * Set up the color array which maps pixels to colors.
@@ -1229,14 +1229,14 @@ static void print_contour_path(float *xy, bool switched, int len,
    * Print the moveto point. The "M" PostScript operator
    * does a "moveto".
    */
-  int px1 = round((x[0] - index_xoffset) * index_xscale);
-  int py1 = round((y[0] - index_yoffset) * index_yscale);
+  int px1 = nearest_int((x[0] - index_xoffset) * index_xscale);
+  int py1 = nearest_int((y[0] - index_yoffset) * index_yscale);
   fprintf(fp, "%d %d M\n", px1, py1);
 
   for (int s = 1 ; s < len ; ++s)
     {
-      int px = round((x[2*s] - index_xoffset) * index_xscale);
-      int py = round((y[2*s] - index_yoffset) * index_yscale);
+      int px = nearest_int((x[2*s] - index_xoffset) * index_xscale);
+      int py = nearest_int((y[2*s] - index_yoffset) * index_yscale);
       fprintf(fp, "%d %d L\n", px, py);
     }
 
@@ -1297,7 +1297,7 @@ makeaxis(
 static int decimals_after_point(double step)
 {
   int prec = 0;
-  for (step = abs(step) ; step < .999 && prec <= 8 ; step *= 10)
+  for (step = fabs(step) ; step < .999 && prec <= 8 ; step *= 10)
     prec += 1;
 
   return prec;
