@@ -117,6 +117,9 @@ Stringy SaveFile::path() const
 void SaveFile::set_path(const Stringy &path)
 {
   Stringy p = tilde_expand(path.cstring());
+  if (!is_absolute_path(p))
+    p = file_path(current_directory(), p);
+  p = dedotify_path(p);
   if (!same_file(p, mPath))
     {
       mPath = p;
