@@ -72,7 +72,7 @@ bool simplex(
       y[i] = (*func)(p[i], fdata);
     }
 
-  int best;
+  int best = 0;
   bool converged = minimize(p, y, pmin, pmax, psum, ptry, ndim,
 			    ftol, maxiterations, func, stoptrying, fdata,
 			    &best);
