@@ -170,7 +170,7 @@ bool catch_signal(int sig, void (*handler)(int))
 {
   struct sigaction action;
 
-  *(void **) &action.sa_handler = (void *) handler;
+  action.sa_handler = handler;
   sigemptyset(&action.sa_mask);
   action.sa_flags = 0;
   
@@ -184,7 +184,7 @@ bool ignore_signal(int sig)
 {
   struct sigaction action;
 
-  *(void **) &action.sa_handler = (void *) SIG_IGN;
+  action.sa_handler = SIG_IGN;
   sigemptyset(&action.sa_mask);
   action.sa_flags = 0;
   
