@@ -13,8 +13,9 @@
 #include "blockfile.h"		// Use Block_File
 #include "memalloc.h"		// use new()
 #include "nmrdata.h"		// Use NMR_Data
-#include "num.h"		// Use round(), min(), max()
+#include "num.h"		// Use nearest_int(), min(), max()
 #include "spoint.h"		// Use IPoint, IRegion
+#include "subarray.h"		// use Subarray_Iterator
 #include "system.h"		// Use file_owner(), get_username()
 #include "ucsffile.h"		// Use is_ucsf_nmr_file()
 #include "utility.h"		// Use fatal_error()
@@ -22,10 +23,10 @@
 // ----------------------------------------------------------------------------
 // File versions.
 //
-#define NMR_UNKNOWN	-1
-#define NMR_CLASSIC	0
-#define NMR_NEW		1
-#define NMR_NEWER	2
+#define NMR_UNKNOWN	((char)-1)
+#define NMR_CLASSIC	((char)0)
+#define NMR_NEW		((char)1)
+#define NMR_NEWER	((char)2)
 
 // ----------------------------------------------------------------------------
 // The version 2 file format has a 180 byte header followed by one 128 byte
@@ -290,13 +291,13 @@ static SPoint nmr_data_spoint(NMR_FILE *nmrfp,
 			      float (*fn)(const NMR_FILE *, int a));
 static SPoint nmr_origin_ppm(NMR_FILE *nmrfp);
 static List nmr_axis_labels(NMR_FILE *nmrfp);
-static int nmr_data_start(NMR_FILE *nmrfp);
+static offset_type nmr_data_start(NMR_FILE *nmrfp);
 
-static int read_version(FILE *fp);
+static char read_version(FILE *fp);
 static bool nmr_file_dimension(const Stringy &path, int *dim, int dimarray[]);
 static NMR_FILE *nmr_open(const Stringy &path);
 static bool nmr_header_read(NMR_FILE *fp, FILE *);
-static long nmr_seekpos(NMR_HEADER *hdr);
+static offset_type nmr_seekpos(NMR_HEADER *hdr);
 static int nmr_file_getaxis(NMR_HEADER *hdr);
 static NMR_HEADER *nmr_file_header(const NMR_FILE *fp);
 static int nmr_file_version(const NMR_FILE *fp);
@@ -386,7 +387,7 @@ NMR_Data *ucsf_nmr_data(const Stringy &path, Memory_Cache *mcache)
   SPoint spectral_width = nmr_spectral_width(nmrfp);
   SPoint origin_ppm = nmr_origin_ppm(nmrfp);
   List axis_labels = nmr_axis_labels(nmrfp);
-  int data_offset = nmr_data_start(nmrfp);
+  offset_type data_offset = nmr_data_start(nmrfp);
 
   Block_File *bf = packed_block_file(path, "rb", size, block_size,
 				     data_offset, true, mcache);
@@ -428,7 +429,8 @@ bool write_ucsf_nmr_data(NMR_Data *nmr_data, const Stringy &path,
   if (bf == NULL)
     { *err_msg = "Failed opening UCSF file."; return false; }
 
-  bf->write_zeros();
+  if (! bf->write_zeros())
+    { *err_msg = "Failed initializing UCSF file with zeros."; return false; }
 
   bool written = write_nmr_data(nmr_data, bf, err_msg);
 
@@ -504,7 +506,7 @@ static List nmr_axis_labels(NMR_FILE *nmrfp)
 
 // ----------------------------------------------------------------------------
 //
-static int nmr_data_start(NMR_FILE *nmrfp)
+static offset_type nmr_data_start(NMR_FILE *nmrfp)
 {
   return NMR_HEADER_IO_SIZE + NMR_AXIS_IO_SIZE * nmr_file_naxes(nmrfp);
 }
@@ -512,7 +514,7 @@ static int nmr_data_start(NMR_FILE *nmrfp)
 /*
  * Returns the version of the NMR file fp.
  */
-static int read_version(FILE *fp)
+static char read_version(FILE *fp)
 {
 	NMR_HEADER	hdr;
 	NMR_HEADER_V0	hv0;
@@ -553,7 +555,7 @@ static bool nmr_file_dimension(const Stringy &path, int *dim, int dimarray[])
 	if (fp == NULL)
 	  return false;
 
-	int		version = read_version(fp);
+	char		version = read_version(fp);
 	NMR_HEADER_V0	hv0;
 	NMR_HEADER	hdr;
 	NMR_AXIS	axis;
@@ -645,8 +647,8 @@ static NMR_FILE *nmr_open(const Stringy &path)
  */
 static bool nmr_header_read(NMR_FILE *fp, FILE *filep)
 {
-	int		i, naxes, version;
-	char		*date;
+	int		i, naxes;
+	char		version, *date;
 	NMR_HEADER_V0	p;
 	NMR_AXIS_V0	*a;
 	NMR_AXIS	*b;
@@ -693,22 +695,22 @@ static bool nmr_header_read(NMR_FILE *fp, FILE *filep)
 		hdr->date[24] = '\0';
 		hdr->axis = new NMR_AXIS [2];
 		memset(hdr->axis, 0, 2 * sizeof(NMR_AXIS));
-		hdr->axis[T1].bsize = hdr->axis[T2].bsize = round(p.t1t2) - 1;
+		hdr->axis[T1].bsize = hdr->axis[T2].bsize = nearest_int(p.t1t2) - 1;
 		if (p.t1t2 == 2.0) {
-			hdr->axis[T1].npoints = round(p.nypoints);
-			hdr->axis[T2].npoints = round(p.nxpoints);
+			hdr->axis[T1].npoints = nearest_int(p.nypoints);
+			hdr->axis[T2].npoints = nearest_int(p.nxpoints);
 		}
 		else {
-			hdr->axis[T1].npoints = round(p.nxpoints);
-			hdr->axis[T2].npoints = round(p.nypoints);
+			hdr->axis[T1].npoints = nearest_int(p.nxpoints);
+			hdr->axis[T2].npoints = nearest_int(p.nypoints);
 		}
 
 		/*
 		 * fill in original axis sizes. May not be originally defined.
 		 */
-		if ((hdr->axis[T1].size = round(p.w1.size)) == 0.0)
+		if ((hdr->axis[T1].size = nearest_int(p.w1.size)) == 0.0)
 			hdr->axis[T1].size = hdr->axis[T1].npoints;
-		if ((hdr->axis[T2].size = round(p.w2.size)) == 0.0)
+		if ((hdr->axis[T2].size = nearest_int(p.w2.size)) == 0.0)
 			hdr->axis[T2].size = hdr->axis[T2].npoints;
 
 
@@ -726,15 +728,15 @@ static bool nmr_header_read(NMR_FILE *fp, FILE *filep)
 			b->apo.p1.shift = a->shift;
 			b->apo.p1.line_broad = a->lb;
 			b->apo.p2.gaussian = a->gn;
-			b->flags.nfills = round(a->n_zero_fills);
+			b->flags.nfills = nearest_int(a->n_zero_fills);
 			b->zero_order = a->zero_order;
 			b->first_order = a->first_order;
-			b->flags.dc_offset = round(a->offset_correct);
-			b->flags.ft_code = round(a->ft_code);
-			b->flags.spectrum_reverse = round(a->spectrum_reverse);
-			b->flags.absolute_value = round(a->abs_val_code);
-			b->flags.baseline_fit = round(a->baseline_correct);
-			b->flags.baseline_offset = round(a->ridge_subtract);
+			b->flags.dc_offset = nearest_int(a->offset_correct);
+			b->flags.ft_code = nearest_int(a->ft_code);
+			b->flags.spectrum_reverse = nearest_int(a->spectrum_reverse);
+			b->flags.absolute_value = nearest_int(a->abs_val_code);
+			b->flags.baseline_fit = nearest_int(a->baseline_correct);
+			b->flags.baseline_offset = nearest_int(a->ridge_subtract);
 			b->status.transformed = (unsigned) p.processed[i];
 			b->spectral_shift = (short) (p.xp.right_shift[i] -
 						     p.xp.left_shift[i]);
@@ -804,7 +806,7 @@ static bool nmr_header_read(NMR_FILE *fp, FILE *filep)
 	 * insure that older file.have seek_pos set properly
 	 */
 	if (hdr->seek_pos == 0)
-		hdr->seek_pos = nmr_seekpos(hdr);
+		hdr->seek_pos = static_cast<long>(nmr_seekpos(hdr));
 
 	/*
 	 * make sure first point scaling factor is set.
@@ -876,11 +878,11 @@ static void convert_axes(NMR_AXIS_V1 *in, NMR_AXIS *out, int naxes)
 	}
 }
 
-static long nmr_seekpos(NMR_HEADER *hdr)
+static offset_type nmr_seekpos(NMR_HEADER *hdr)
 {
 	NMR_AXIS	*a;
 	int	nx, ny, nblocks;
-	long		seekpos;
+	offset_type	seekpos;
 
 	if (hdr->version == NMR_CLASSIC) {
 
@@ -1180,7 +1182,7 @@ static bool nmr_header_write(NMR_FILE *fp, NMR_HEADER *hdr, FILE *filep)
 	const char	*fname;
 
 
-	hdr->seek_pos = nmr_seekpos(hdr);
+	hdr->seek_pos = static_cast<long>(nmr_seekpos(hdr));
 	fname = nmr_file_path(fp);
 	naxes = (int) hdr->naxis;
 
@@ -1625,10 +1627,14 @@ static bool write_nmr_data(NMR_Data *nmr_data, Block_File *bf,
 {
   int dim = nmr_data->dimension();
   IPoint block_size(dim);
+  offset_type volume = 1;
   for (int a = 0 ; a < dim ; ++a)
-    block_size[a] = max(nmr_data->block_size()[a], bf->block_size()[a]);
+    {
+      int bs = max(nmr_data->block_size()[a], bf->block_size()[a]);
+      block_size[a] = bs;
+      volume *= bs;
+    }
 
-  int volume = block_size.product();
   float *values = new float [volume];
 
   IRegion bspace = block_space(bf->size(), block_size);
@@ -1778,6 +1784,11 @@ static int read_nmr_axis(NMR_AXIS *axis, FILE *fp)
 	  );
 }
 
+/* ----------------------------------------------------------------------------
+*/
+static unsigned int unsigned_int_bit_field_bits(bit_field bf, int b1, int b2)
+  { return static_cast<unsigned int>(bit_field_bits(bf, b1, b2)); }
+
 /* ----------------------------------------------------------------------------
 */
 static int read_nmr_processed(NMR_PROCESSED *p, FILE *fp)
@@ -1786,9 +1797,9 @@ static int read_nmr_processed(NMR_PROCESSED *p, FILE *fp)
 
   if (read_bit_field(bf, fp))
     {
-      p->transformed = bit_field_bits(bf, 0, 0);
-      p->base_corrected = bit_field_bits(bf, 1, 1);
-      p->reserved = bit_field_bits(bf, 2, 15);
+      p->transformed = unsigned_int_bit_field_bits(bf, 0, 0);
+      p->base_corrected = unsigned_int_bit_field_bits(bf, 1, 1);
+      p->reserved = unsigned_int_bit_field_bits(bf, 2, 15);
 
       return 1;
     }
@@ -1804,19 +1815,19 @@ static int read_nmr_flag(NMR_FLAG *flags, FILE *fp)
 
   if (read_bit_field(bf, fp))
     {
-      flags->fid_convolution = bit_field_bits(bf, 0, 1);
-      flags->dc_offset = bit_field_bits(bf, 2, 2);
-      flags->forward_extend = bit_field_bits(bf, 3, 3);
-      flags->backwards_extend = bit_field_bits(bf, 4, 4);
-      flags->replace = bit_field_bits(bf, 5, 6);
-      flags->apodization = bit_field_bits(bf, 7, 10);
-      flags->ft_code = bit_field_bits(bf, 11, 12);
-      flags->nfills = bit_field_bits(bf, 13, 16);
-      flags->absolute_value = bit_field_bits(bf, 17, 17);
-      flags->spectrum_reverse = bit_field_bits(bf, 18, 18);
-      flags->baseline_offset = bit_field_bits(bf, 19, 19);
-      flags->baseline_fit = bit_field_bits(bf, 20, 21);
-      flags->reserved = bit_field_bits(bf, 22, 31);
+      flags->fid_convolution = unsigned_int_bit_field_bits(bf, 0, 1);
+      flags->dc_offset = unsigned_int_bit_field_bits(bf, 2, 2);
+      flags->forward_extend = unsigned_int_bit_field_bits(bf, 3, 3);
+      flags->backwards_extend = unsigned_int_bit_field_bits(bf, 4, 4);
+      flags->replace = unsigned_int_bit_field_bits(bf, 5, 6);
+      flags->apodization = unsigned_int_bit_field_bits(bf, 7, 10);
+      flags->ft_code = unsigned_int_bit_field_bits(bf, 11, 12);
+      flags->nfills = unsigned_int_bit_field_bits(bf, 13, 16);
+      flags->absolute_value = unsigned_int_bit_field_bits(bf, 17, 17);
+      flags->spectrum_reverse = unsigned_int_bit_field_bits(bf, 18, 18);
+      flags->baseline_offset = unsigned_int_bit_field_bits(bf, 19, 19);
+      flags->baseline_fit = unsigned_int_bit_field_bits(bf, 20, 21);
+      flags->reserved = unsigned_int_bit_field_bits(bf, 22, 31);
 
       return 1;
     }
@@ -2134,7 +2145,7 @@ bool change_ucsf_axis_label(const Stringy &path, int axis,
   if (fp == NULL)
     return false;
 
-  long offset = (long) (NMR_HEADER_IO_SIZE + axis * NMR_AXIS_IO_SIZE);
+  offset_type offset = NMR_HEADER_IO_SIZE + axis * NMR_AXIS_IO_SIZE;
   bool success = (seek_position(fp, offset, 0) &&
 		  write_u8_array(nucleus_name, 6, fp));
   fclose(fp);
@@ -2167,7 +2178,7 @@ bool change_ucsf_origin(const Stringy &path, int axis, float origin_ppm)
   if (fp == NULL)
     return false;
 
-  long offset = (long) (NMR_HEADER_IO_SIZE + axis * NMR_AXIS_IO_SIZE + 28);
+  offset_type offset = NMR_HEADER_IO_SIZE + axis * NMR_AXIS_IO_SIZE + 28;
   bool success = (seek_position(fp, offset, 0) && write_f32(xmtr_freq, fp));
   fclose(fp);
 
@@ -2215,8 +2226,7 @@ static bool change_ucsf_header_value(const Stringy &path, int axis,
   if (fp == NULL)
     return false;
 
-  long file_offset = (long) (NMR_HEADER_IO_SIZE + axis * NMR_AXIS_IO_SIZE
-			     + offset);
+  offset_type file_offset = NMR_HEADER_IO_SIZE + axis * NMR_AXIS_IO_SIZE + offset;
   bool success = (seek_position(fp, file_offset, 0) && write_f32(value, fp));
   fclose(fp);
 
