@@ -45,14 +45,14 @@ Resonance_Field::Resonance_Field(Session &s, Widget parent,
 
   ws.column_attachments(res, cond, res, END_OF_WIDGETS);
 
-  update_resonance_menu(this);
+  update_resonance_menu();
 }
 
 // ----------------------------------------------------------------------------
 //
 Resonance_Field::~Resonance_Field()
 {
-  ws.remove_work_procedure(update_resonance_menu, this);
+  ws.remove_work_procedure(update_resonance_menu_cb, this);
   Notifier &n = session.notifier();
   n.dont_notify_me(nt_added_condition_to_molecule,
 		 condition_list_changed_cb, this);
@@ -143,7 +143,7 @@ void Resonance_Field::set_resonance_field(const Resonance *r)
 void Resonance_Field::condition_changed_cb(Widget, CB_Data rfield, CB_Data)
 {
   Resonance_Field *rf = (Resonance_Field *) rfield;
-  rf->ws.add_work_procedure(update_resonance_menu, rfield);
+  rf->ws.add_work_procedure(update_resonance_menu_cb, rfield);
 }
 
 // ----------------------------------------------------------------------------
@@ -151,22 +151,36 @@ void Resonance_Field::condition_changed_cb(Widget, CB_Data rfield, CB_Data)
 void Resonance_Field::resonance_list_changed_cb(void *rfield, void *)
 {
   Resonance_Field *rf = (Resonance_Field *) rfield;
-  rf->ws.add_work_procedure(update_resonance_menu, rfield);
+  rf->ws.add_work_procedure(update_resonance_menu_cb, rfield);
 }
 
 // ----------------------------------------------------------------------------
 //
-void Resonance_Field::update_resonance_menu(void *rfield)
+void Resonance_Field::update_resonance_menu_cb(void *rfield)
 {
   Resonance_Field *rf = (Resonance_Field *) rfield;
-  Stringy mcname = rf->ws.edit_value(rf->cond);
-  Condition *c = named_condition(rf->session.project().condition_list(),
-				 mcname);
+  rf->update_resonance_menu();
+}
 
-  Widget resedit = rf->res;
-  Widget resmenu = rf->ws.edit_field_menu(resedit);
-  Widget group_pane = rf->ws.menu_pane(resmenu);
-  rf->ws.delete_menu_buttons(group_pane);
+// ----------------------------------------------------------------------------
+//
+void Resonance_Field::update_resonance_menu()
+{
+  Stringy mcname = ws.edit_value(cond);
+  Condition *c = named_condition(session.project().condition_list(), mcname);
+
+  // Delete menu recreate it with current resonances.
+  Widget resmenu = ws.edit_field_menu(res);
+
+  //
+  // To delete all cascade panes, delete and recreate parent group pane.
+  // Using delete_menu_buttons() on the group pane is insufficient since
+  // it does not delete the cascade menu panes.
+  //
+  Widget group_pane = ws.menu_pane(resmenu);
+  ws.delete_widget(group_pane);
+  group_pane = ws.create_menu_pane(resmenu, "menu");
+  ws.set_menu_pane(resmenu, group_pane);
 
   if (c)
     {
@@ -175,17 +189,16 @@ void Resonance_Field::update_resonance_menu(void *rfield)
       for (int gi = 0 ; gi < glist.size() ; ++gi)
 	{
 	  Group *g = (Group *) glist[gi];
-	  Widget atom_pane = rf->ws.cascade_pane(group_pane, g->name());
+	  Widget atom_pane = ws.cascade_pane(group_pane, g->name());
 	  List alist = c->molecule()->AtomList(g);
 	  for (int ai = 0 ; ai < alist.size() ; ++ai)
 	    {
 	      Atom *a = (Atom *) alist[ai];
-	      rf->ws.add_edit_field_menu_entry(atom_pane, a->LongName(),
-					       resedit);
+	      ws.add_edit_field_menu_entry(atom_pane, a->LongName(), res);
 	    }
 	}
     }
-  rf->ws.square_up_menu(resmenu);
+  ws.square_up_menu(resmenu);
 }
 
 // ----------------------------------------------------------------------------
