@@ -274,6 +274,7 @@ void Drawing::repaint_tile(CB_Data dr)
   Rectangle rect = d->repaint_region().first_rectangle();
   Rectangle tile = first_tile(rect, d->redraw_tile);
   d->repaint_reg.subtract(tile);
+  tile.clip(d->drawing_rectangle());
   d->redraw_rectangle(tile);
 
   if (!d->repaint_region().is_empty())
@@ -393,7 +394,7 @@ const Region2 &Drawing::repaint_region()
 //
 void Drawing::update_font_height()
 {
-  int pixel_height = bounded(1, round(font_height / pixel_size(Y)), 100);
+  int pixel_height = bounded(1, nearest_int(font_height / pixel_size(Y)), 100);
   c->set_font_height(pixel_height);
 }
 
@@ -459,8 +460,8 @@ Rectangle Drawing::drawing_rectangle() const
 //
 void Drawing::paint_coordinates(double x, double y, int *px, int *py)
 {
-  *px = round(.5 * vw - (x - x_center) / x_pixel_size);
-  *py = round(.5 * vh + (y - y_center) / y_pixel_size);
+  *px = nearest_int(.5 * vw - (x - x_center) / x_pixel_size);
+  *py = nearest_int(.5 * vh + (y - y_center) / y_pixel_size);
 }
 
 // ----------------------------------------------------------------------------
@@ -476,16 +477,16 @@ void Drawing::drawing_coordinates(int px, int py, double *x, double *y)
 int Drawing::paint_coordinate(double d, Axis a)
 {
   return (a == X ?
-	  round(.5 * vw - (d - x_center) / x_pixel_size) :
-	  round(.5 * vh + (d - y_center) / y_pixel_size));
+	  nearest_int(.5 * vw - (d - x_center) / x_pixel_size) :
+	  nearest_int(.5 * vh + (d - y_center) / y_pixel_size));
 }
 
 // ----------------------------------------------------------------------------
 //
 void Drawing::translate_view(double delta_x, double delta_y)
 {
-  int dx = round(delta_x / pixel_size(X));
-  int dy = round(delta_y / pixel_size(Y));
+  int dx = nearest_int(delta_x / pixel_size(X));
+  int dy = nearest_int(delta_y / pixel_size(Y));
 
 // This is used before changing the mapping between X window coordinates
 // and the image coordinates in translate_view().  If pretranslation exposure
