@@ -8,7 +8,7 @@
 #include "reporter.h"		// use Reporter
 #include "session.h"		// use Session
 #include "stringc.h"		// use Stringy
-#include "system.h"		// use show_url()
+#include "system.h"		// use show_url(), path_separator()
 #include "uidialogs.h"		// use show_manual_url()
 #include "uimain.h"		// use query()
 #include "utility.h"		// use warning()
@@ -32,6 +32,7 @@ void show_manual_url(Session &s, const Stringy &manual_url)
   Stringy mandir = installation_path(SPARKY_MANUAL);
   Stringy page = (manual_url.is_empty() ? Stringy("index.html") : manual_url);
   Stringy path = file_path(mandir, page);
+  path = replace_character(path, path_separator().cstring()[0], '/');
   Stringy url = "file://" + path;
   Stringy error_msg;
   if (!show_url(url, &error_msg))
