@@ -347,7 +347,7 @@ static void update_view_menu(Widget pane, Session &s)
 {
   WinSys &ws = s.window_system();
   ws.delete_menu_buttons(pane);
-  List vlist = s.project().view_list();
+  List vlist = s.project().top_level_views();
   for (int vi = 0 ; vi < vlist.size() ; ++vi)
     {
       View *v = (View *) vlist[vi];
