@@ -7,7 +7,7 @@
 #ifndef _Undo_h
 #define _Undo_h
 
-#include <strstream.h>		// use ostrstream
+#include <sstream>		// use ostringstream
 
 #include "objectid.h"		// use Object_Table
 #include "stringc.h"		// use Stringy
@@ -34,7 +34,7 @@ private:
   Stringy	mUndoMsg;	// msg. at start of undo.
   int		mCount;		// number of ornaments saved
   Object_Table	ids;		// for ornaments that point to others
-  ostrstream	*mOut;		// state saved to here
+  std::ostringstream	*mOut;	// state saved to here
 
   static void will_delete_ornament_cb(void *undo, void *ornament);
 };
