@@ -259,8 +259,8 @@ static bool read_varian_parameters(const Stringy &procpar,
 				   SPoint *origin_ppm,
 				   Stringy *error_msg)
 {
-  bool trans;
-  int bhsize;
+  bool trans = false;
+  int bhsize = 0;
   IPoint sz, bsize;
   SPoint sfreq, swidth, orig;
   
