@@ -1,7 +1,7 @@
 #!/bin/sh
 
 SPARKY_APP=`dirname "$0"`/../..
-SPARKY=$SPARKY_APP/Contents/Resources
+SPARKY="$SPARKY_APP/Contents/Resources"
 
 if [ ! "$DISPLAY" ]
 then
