@@ -89,16 +89,17 @@ class peak_table_dialog(tkutil.Dialog, tkutil.Stoppable):
   #
   def assigned_peaks(self, spectra):
 
-    peaks = {}
+    s2a = {}
     for spectrum in spectra:
-      peaks[spectrum] = {}
+      s2a[spectrum] = {}
       self.stoppable_loop(spectrum.name + ' peaks', 100)
       for peak in spectrum.peak_list():
 	self.check_for_stop()
         a = self.assignment(peak)
 	if a:
-	  peaks[spectrum][a] = peak
+	  s2a[spectrum][a] = peak
 
+    peaks = map(lambda s: (s,s2a[s]), spectra)
     return peaks
 
   # ---------------------------------------------------------------------------
@@ -118,9 +119,8 @@ class peak_table_dialog(tkutil.Dialog, tkutil.Stoppable):
   def show_assignments(self, peaks):
 
     assignments = {}
-    spectra = peaks.keys()
-    for spectrum in spectra:
-      for a in peaks[spectrum].keys():
+    for spectrum, assigned_peaks in peaks:
+      for a in assigned_peaks.keys():
 	assignments[a] = 1
 
     if self.noesy:
@@ -140,6 +140,7 @@ class peak_table_dialog(tkutil.Dialog, tkutil.Stoppable):
       self.check_for_stop()
       self.show_assignment(assignment, peaks)
 
+    spectra = map(lambda s_ap: s_ap[0], peaks)
     self.set_column_ranges(spectra)
     count = self.peak_list.listbox.index('end')
     self.peak_list.heading['text'] = '%d assignments\n' % count + self.heading
@@ -156,12 +157,11 @@ class peak_table_dialog(tkutil.Dialog, tkutil.Stoppable):
   def assignment_line(self, assignment, peaks):
 
     line = '%-20s' % self.assignment_name(assignment)
-    spectra = peaks.keys()
-    for spectrum in peaks.keys():
-      line = line + self.peak_field(assignment, spectrum, peaks)
+    for spectrum, assigned_peaks in peaks:
+      line = line + self.peak_field(assignment, spectrum, assigned_peaks)
       if self.noesy:
 	crossdiag = (assignment[1], assignment[0])
-	line = line + self.peak_field(crossdiag, spectrum, peaks)
+	line = line + self.peak_field(crossdiag, spectrum, assigned_peaks)
 
     return line
 
@@ -175,10 +175,10 @@ class peak_table_dialog(tkutil.Dialog, tkutil.Stoppable):
 
   # ---------------------------------------------------------------------------
   #
-  def peak_field(self, assignment, spectrum, peaks):
+  def peak_field(self, assignment, spectrum, assigned_peaks):
 
-    if peaks[spectrum].has_key(assignment):
-      peak = peaks[spectrum][assignment]
+    if assigned_peaks.has_key(assignment):
+      peak = assigned_peaks[assignment]
       if peak.volume:
 	return '%10.2e' % peak.volume
       else:
